@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Conflicts;
 BEGIN {
-  $Dist::Zilla::Plugin::Conflicts::VERSION = '0.04';
+  $Dist::Zilla::Plugin::Conflicts::VERSION = '0.05';
 }
 
 use strict;
@@ -113,9 +113,7 @@ use Dist::CheckConflicts
     -conflicts => {
         {{ $conflicts_dump }},
     },
-    -also => [ qw(
-        {{ $also_dump }}
-    ) ],
+{{ $also_dump }}
 ;
 
 1;
@@ -134,6 +132,13 @@ sub _build_conflicts_file {
         map { $_->required_modules() }
         $self->zilla()->prereqs()->requirements_for(qw(runtime requires));
 
+    $also_dump
+        = '    -also => [ qw(' . "\n"
+        . '        '
+        . $also_dump . "\n"
+        . '    ) ],' . "\n"
+        if length $also_dump;
+
     ( my $dist_name = $self->zilla()->name() ) =~ s/-/::/g;
 
     my $content = $self->fill_in_string(
@@ -250,10 +255,7 @@ sub check_conflicts {
     else {
         print <<'EOF';
 ***
-    Your toolchain doesn't support configure_requires, so Dist::CheckConflicts
-    hasn't been installed yet. You should check for conflicting modules
-    manually using the 'package-stash-conflicts' script that is installed with
-    this distribution once the installation finishes.
+{{ $warning }}
 ***
 EOF
     }
@@ -269,10 +271,33 @@ CC_SUB
 sub _check_conflicts_sub {
     my $self = shift;
 
+    my $warning;
+    if ( $self->_has_script() ) {
+        ( my $filename = $self->_script() ) =~ s+^.*/++;
+        $warning = <<"EOF";
+    Your toolchain doesn't support configure_requires, so Dist::CheckConflicts
+    hasn't been installed yet. You should check for conflicting modules
+    manually using the '$filename' script that is installed with
+    this distribution once the installation finishes.
+EOF
+    }
+    else {
+        my $mod = $self->_conflicts_module_name();
+        $warning = <<"EOF";
+    Your toolchain doesn't support configure_requires, so Dist::CheckConflicts
+    hasn't been installed yet. You should check for conflicting modules
+    manually by examining the list of conflicts in $mod once the installation
+    finishes.
+EOF
+    }
+
+    chomp $warning;
+
     return $self->fill_in_string(
         $check_conflicts_template, {
             conflicts_module_path => \( $self->_conflicts_module_path() ),
             conflicts_module_name => \( $self->_conflicts_module_name() ),
+            warning               => \$warning,
         },
     );
 }
@@ -301,7 +326,7 @@ Dist::Zilla::Plugin::Conflicts - Declare conflicts for your distro
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -390,7 +415,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by Dave Rolsky.
+This software is Copyright (c) 2011 by Dave Rolsky.
 
 This is free software, licensed under:
 
